work_at_angle

Function work_at_angle 

pub fn work_at_angle(
    force: f64,
    displacement: f64,
    angle_radians: f64,
) -> Option<f64>
Computes mechanical work when the force is applied at an angle to the displacement.

Formula: W = F * d * cos(theta)

Returns None when any input is not finite or when the computed result is not finite. The angle_radians input is interpreted in radians.

Examples

use use_work::work_at_angle;

let result = work_at_angle(10.0, 2.0, 0.0).unwrap();

assert_eq!(result, 20.0);