work_by_friction

Function work_by_friction 

pub fn work_by_friction(
    friction_force_magnitude: f64,
    displacement: f64,
) -> Option<f64>
Computes work done by kinetic friction.

Formula: W = -f_k * abs(d)

Returns None when friction_force_magnitude is negative, when any input is not finite, or when the computed result is not finite.